import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixForumV1Post from './forum-v1-post-posts.http.js';
import { transformRESTImageToSDKImage } from '@wix/sdk-runtime/transformations/image';
import { transformRESTVideoV2ToSDKVideoV2 } from '@wix/sdk-runtime/transformations/video-v2';
import { transformRESTPageURLToSDKPageURL } from '@wix/sdk-runtime/transformations/page-url';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var PostType;
(function (PostType) {
    PostType["DISCUSSION"] = "DISCUSSION";
    PostType["QUESTION"] = "QUESTION";
})(PostType || (PostType = {}));
export var Interaction;
(function (Interaction) {
    Interaction["UNKNOWN"] = "UNKNOWN";
    Interaction["REACTION"] = "REACTION";
    Interaction["VOTE"] = "VOTE";
    Interaction["NONE"] = "NONE";
})(Interaction || (Interaction = {}));
export var EntityType;
(function (EntityType) {
    EntityType["UNKNOWN"] = "UNKNOWN";
    EntityType["COMMENT"] = "COMMENT";
    EntityType["REPLY"] = "REPLY";
})(EntityType || (EntityType = {}));
export var IdentityType;
(function (IdentityType) {
    IdentityType["UNKNOWN"] = "UNKNOWN";
    IdentityType["VISITOR"] = "VISITOR";
    IdentityType["MEMBER"] = "MEMBER";
})(IdentityType || (IdentityType = {}));
export var ReportType;
(function (ReportType) {
    ReportType["OFFENSIVE_CONTENT"] = "OFFENSIVE_CONTENT";
    ReportType["OFFENSIVE_MEDIA"] = "OFFENSIVE_MEDIA";
    ReportType["SPAM"] = "SPAM";
})(ReportType || (ReportType = {}));
export var PostFieldField;
(function (PostFieldField) {
    PostFieldField["UNKNOWN"] = "UNKNOWN";
    /** Includes Post content as a stringified DraftJS document (internal only). */
    PostFieldField["CONTENT"] = "CONTENT";
    /** Includes images from Post content (internal only). */
    PostFieldField["IMAGES"] = "IMAGES";
    /** Includes videos from Post content (internal only). */
    PostFieldField["VIDEOS"] = "VIDEOS";
    /** Includes Post URL. */
    PostFieldField["URL"] = "URL";
    /** Includes Post content as a stringified Rich Content document (internal only). */
    PostFieldField["RICH_CONTENT"] = "RICH_CONTENT";
})(PostFieldField || (PostFieldField = {}));
export var Field;
(function (Field) {
    /** Undefined field type. */
    Field["UNKNOWN"] = "UNKNOWN";
    /** Include images from post content. */
    Field["IMAGES"] = "IMAGES";
    /** Include videos from post content. */
    Field["VIDEOS"] = "VIDEOS";
    /** Include post URL. */
    Field["URL"] = "URL";
    /** Include reaction identities. */
    Field["REACTION_IDENTITIES"] = "REACTION_IDENTITIES";
    /** Includes the post content as a stringified [Rich Content document](https://dev.wix.com/docs/ricos/api-reference/ricos-document) */
    Field["RICH_CONTENT"] = "RICH_CONTENT";
})(Field || (Field = {}));
export var Order;
(function (Order) {
    /** Sort by ascending order. */
    Order["ASC"] = "ASC";
    /** Sort by descending order. */
    Order["DESC"] = "DESC";
})(Order || (Order = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Retrieves a single post by ID.
 * @param postId - Post ID.
 * @public
 * @documentationMaturity preview
 * @requiredField postId
 * @param options - Options specifying which additional fields to return.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @returns Post for the provided post ID.
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.GetPost
 * @deprecated
 * @targetRemovalDate 2025-04-15
 */
export async function getPost(postId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        postId: postId,
        extraFields: options?.extraFields,
    });
    const reqOpts = ambassadorWixForumV1Post.getPost(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLToSDKPageURL,
                paths: [{ path: 'post.url' }],
            },
            {
                transformFn: transformRESTImageToSDKImage,
                paths: [{ path: 'post.images', isRepeated: true }],
            },
            {
                transformFn: transformRESTVideoV2ToSDKVideoV2,
                paths: [{ path: 'post.videos', isRepeated: true }],
            },
        ]))?.post;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                postId: '$[0]',
                extraFields: '$[1].extraFields',
            },
            singleArgumentUnchanged: false,
        }, ['postId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a single post by URL slug.
 * @param slug - URL slug.
 * @public
 * @documentationMaturity preview
 * @requiredField slug
 * @param options - Options specifying which additional fields to return.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.GetPostBySlug
 * @deprecated
 * @targetRemovalDate 2025-04-15
 */
export async function getPostBySlug(slug, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        slug: slug,
        extraFields: options?.extraFields,
    });
    const reqOpts = ambassadorWixForumV1Post.getPostBySlug(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLToSDKPageURL,
                paths: [{ path: 'post.url' }],
            },
            {
                transformFn: transformRESTImageToSDKImage,
                paths: [{ path: 'post.images', isRepeated: true }],
            },
            {
                transformFn: transformRESTVideoV2ToSDKVideoV2,
                paths: [{ path: 'post.videos', isRepeated: true }],
            },
        ]));
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                slug: '$[0]',
                extraFields: '$[1].extraFields',
            },
            singleArgumentUnchanged: false,
        }, ['slug', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Returns a list of posts by query.
 *
 * Paging
 * - limit: default - 10, min - 0, max - 100
 * - offset: default - 0, min - 0
 *
 * Filterable fields:
 * - id
 * - categoryId
 * - ownerId
 * - title
 * - contentText
 * - bestAnswerCommentId
 * - pinned
 * - commentingEnabled
 * - commentCount
 * - likeCount
 * - viewCount
 * - createdDate
 * - editedDate
 * - lastActivityDate
 * - slug
 *
 * Sortable fields:
 * - lastActivityDate
 * - createdDate
 * - commentCount
 * - viewCount
 * - likeCount
 * - pinned
 * @public
 * @documentationMaturity preview
 * @param options - Options for sorting, filtering, paging, and specifying return fields.
 * @permissionId WIX_FORUM.POST_READ
 * @permissionScope Read Forums
 * @permissionScopeId SCOPE.DC-FORUM.READ-FORUM
 * @permissionScope Manage Forums
 * @permissionScopeId SCOPE.DC-FORUM.MANAGE-FORUM
 * @applicableIdentity APP
 * @fqn com.wixpress.npm.communities.forum.api.PostManagementService.QueryPosts
 * @deprecated
 * @targetRemovalDate 2025-10-15
 */
export async function queryPosts(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        paging: options?.paging,
        filter: options?.filter,
        sort: options?.sort,
        extraFields: options?.extraFields,
    });
    const reqOpts = ambassadorWixForumV1Post.queryPosts(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLToSDKPageURL,
                paths: [{ path: 'posts.url' }],
            },
            {
                transformFn: transformRESTImageToSDKImage,
                paths: [{ path: 'posts.images', isRepeated: true }],
            },
            {
                transformFn: transformRESTVideoV2ToSDKVideoV2,
                paths: [{ path: 'posts.videos', isRepeated: true }],
            },
        ]));
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                paging: '$[0].paging',
                filter: '$[0].filter',
                sort: '$[0].sort',
                extraFields: '$[0].extraFields',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=forum-v1-post-posts.universal.js.map